package storage

import (
	"github.com/KevoDB/kevo/pkg/wal"
	"path/filepath"
)

// WALManagerAdapter adapts a wal.WAL to the WALManager interface
type WALManagerAdapter struct {
	wal *wal.WAL
}

// NewWALManagerAdapter creates a new WALManagerAdapter
func NewWALManagerAdapter(walInstance *wal.WAL) *WALManagerAdapter {
	return &WALManagerAdapter{
		wal: walInstance,
	}
}

func (w *WALManagerAdapter) Append(opType byte, key, value []byte) (uint64, error) {
	return w.wal.Append(opType, key, value)
}

func (w *WALManagerAdapter) AppendBatch(entries []*wal.Entry) (uint64, error) {
	return w.wal.AppendBatch(entries)
}

func (w *WALManagerAdapter) UpdateNextSequence(seqNum uint64) {
	w.wal.UpdateNextSequence(seqNum)
}

func (w *WALManagerAdapter) Rotate() error {
	// Get the configuration from the WAL
	walOpts := w.wal.Options()
	
	// Get the WAL directory
	walDir := filepath.Dir(w.wal.FilePath())
	
	// Close the current WAL
	if err := w.wal.Close(); err != nil {
		return err
	}

	// Create a new WAL with the same settings
	newWal, err := wal.NewWAL(walOpts, walDir)
	if err != nil {
		return err
	}

	w.wal = newWal
	return nil
}

func (w *WALManagerAdapter) Close() error {
	return w.wal.Close()
}