package wal

import (
	"github.com/KevoDB/kevo/pkg/config"
	"os"
	"path/filepath"
)

// Options returns a copy of the configuration used by the WAL
func (w *WAL) Options() *config.Config {
	return w.cfg
}

// FilePath returns the path to the current WAL file
func (w *WAL) FilePath() string {
	if w.file == nil {
		// Return a default path if the file isn't open
		return filepath.Join(w.dir, "current.wal")
	}
	return w.file.Name()
}

// FindWALDir tries to locate a WAL directory
func FindWALDir(startDir string) (string, error) {
	// First check if the startDir contains WAL files
	entries, err := os.ReadDir(startDir)
	if err == nil {
		for _, entry := range entries {
			if !entry.IsDir() && filepath.Ext(entry.Name()) == ".wal" {
				return startDir, nil
			}
		}
	}
	
	// Try common subdirectories
	possibleDirs := []string{
		filepath.Join(startDir, "wal"),
		filepath.Join(startDir, "data", "wal"),
	}
	
	for _, dir := range possibleDirs {
		if _, err := os.Stat(dir); err == nil {
			return dir, nil
		}
	}
	
	// Return the default if nothing else works
	return filepath.Join(startDir, "wal"), nil
}